==> ejc-jlcost-impl-3.0.0-20240524.094601-84-sources.jar: com/ejianc/business/jlcost/finance/service/impl/LoadApplyBpmServiceImpl.java <==
package com.ejianc.business.jlcost.finance.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.ejianc.business.jlcost.finance.bean.BackEntity;
import com.ejianc.business.jlcost.finance.bean.LoadApplyEntity;
import com.ejianc.business.jlcost.finance.bean.ReimburseEntity;
import com.ejianc.business.jlcost.finance.service.IBackService;
import com.ejianc.business.jlcost.finance.service.ILoadApplyService;
import com.ejianc.business.jlcost.finance.service.IReimburseService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

import java.util.Map;

@Service("loadApply")
public class LoadApplyBpmServiceImpl implements ICommonBusinessService {
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBackService backService;

    @Autowired
    private IReimburseService reimburseService;
    @Autowired
    private ILoadApplyService loadApplyService;

    /**
     * 提交前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    ;

    /**
     * 提交完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 有审批流的撤回前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 有审批流的撤回后回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 审批节点审批中时节点审批前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
        return CommonResponse.success();
    }

    ;

    /**
     * 审批节点审批中时节点审批后回调
     *
     * @param billId       //单据id
     * @param state        //单据状态
     * @param billTypeCode //单据类型code
     * @param taskId       //该流程id
     * @param isEnd        //该节点是否结束
     * @return
     */
    @Override
    public CommonResponse<String> afterInApprovalBack(Long billId, Integer state, String billTypeCode, String taskId, Boolean isEnd, String sign, Map<String, Object> other) {
        return CommonResponse.success();
    }

    ;

    /**
     * 终审审核前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 终审审核完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        LambdaQueryWrapper<LoadApplyEntity> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(LoadApplyEntity::getId,billId);
        LoadApplyEntity entity = loadApplyService.getOne(wrapper);
        entity.setStatus(2);
        loadApplyService.updateById(entity);

        //TODO
        return CommonResponse.success();
    }

    /**
     * 弃审前事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {

        logger.info(" 弃审开始");

        LambdaQueryWrapper<BackEntity> backWrapper = new LambdaQueryWrapper<>();
        backWrapper.eq(BackEntity::getApplyId, billId);
        backWrapper.eq(BackEntity::getDr, 0);

        LambdaQueryWrapper<ReimburseEntity> reimburseWrapper = new LambdaQueryWrapper<>();
        reimburseWrapper.eq(ReimburseEntity::getApplyId, billId);
        reimburseWrapper.eq(ReimburseEntity::getDr, 0);
        BackEntity backEntity = backService.getOne(backWrapper);
        ReimburseEntity reimburseEntity = reimburseService.getOne(reimburseWrapper);


        logger.info("backEntity:{},reimburseEntity:{} " + backEntity, reimburseEntity);
        if (!ObjectUtils.isEmpty(backEntity) || !ObjectUtils.isEmpty(reimburseEntity)) {
                return CommonResponse.error("下游存在引用数据，无法撤回");
        }
        LambdaQueryWrapper<LoadApplyEntity> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(LoadApplyEntity::getId,billId);
        LoadApplyEntity entity = loadApplyService.getOne(wrapper);
        entity.setStatus(1);
        loadApplyService.updateById(entity);

        // TODO
        return CommonResponse.success();
    }

    /**
     * 弃审后事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

}

==> ejc-jlcost-impl-3.0.0-20240823.002531-237-sources.jar: com/ejianc/business/jlcost/finance/service/impl/LoadApplyBpmServiceImpl.java <==
package com.ejianc.business.jlcost.finance.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.ejianc.business.jlcost.finance.bean.BackEntity;
import com.ejianc.business.jlcost.finance.bean.LoadApplyEntity;
import com.ejianc.business.jlcost.finance.bean.ReimburseEntity;
import com.ejianc.business.jlcost.finance.mapper.BackMapper;
import com.ejianc.business.jlcost.finance.mapper.LoadApplyMapper;
import com.ejianc.business.jlcost.finance.mapper.ReimburseMapper;
import com.ejianc.business.jlcost.finance.service.IBackService;
import com.ejianc.business.jlcost.finance.service.ILoadApplyService;
import com.ejianc.business.jlcost.finance.service.IReimburseService;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.kit.collection.ListUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

import java.util.List;
import java.util.Map;

@Service("loadApply")
public class LoadApplyBpmServiceImpl implements ICommonBusinessService {
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBackService backService;

    @Autowired
    private IReimburseService reimburseService;
    @Autowired
    private ILoadApplyService loadApplyService;
    @Autowired
    private SessionManager sessionManager;

    @Autowired
    private BackMapper backMapper;

    @Autowired
    private ReimburseMapper reimburseMapper;

    /**
     * 提交前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    ;

    /**
     * 提交完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 有审批流的撤回前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 有审批流的撤回后回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 审批节点审批中时节点审批前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
        return CommonResponse.success();
    }

    ;

    /**
     * 审批节点审批中时节点审批后回调
     *
     * @param billId       //单据id
     * @param state        //单据状态
     * @param billTypeCode //单据类型code
     * @param taskId       //该流程id
     * @param isEnd        //该节点是否结束
     * @return
     */
    @Override
    public CommonResponse<String> afterInApprovalBack(Long billId, Integer state, String billTypeCode, String taskId, Boolean isEnd, String sign, Map<String, Object> other) {
        return CommonResponse.success();
    }

    ;

    /**
     * 终审审核前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 终审审核完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        LambdaQueryWrapper<LoadApplyEntity> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(LoadApplyEntity::getId,billId);
        LoadApplyEntity entity = loadApplyService.getOne(wrapper);
        entity.setStatus(2);
        loadApplyService.updateById(entity);

        //TODO
        return CommonResponse.success();
    }

    /**
     * 弃审前事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {

        logger.info(" 弃审开始");
        //获取当前登录人的信息
        Long employeeId = sessionManager.getUserContext().getEmployeeId();
        LambdaQueryWrapper<BackEntity> backWrapper = new LambdaQueryWrapper<>();
        backWrapper.eq(BackEntity::getApplyId, billId);
        backWrapper.eq(BackEntity::getDr, 0);
        backWrapper.eq(BackEntity::getEmployeeId,employeeId);

        LambdaQueryWrapper<ReimburseEntity> reimburseWrapper = new LambdaQueryWrapper<>();
        reimburseWrapper.eq(ReimburseEntity::getApplyId, billId);
        reimburseWrapper.eq(ReimburseEntity::getDr, 0);
        reimburseWrapper.eq(ReimburseEntity::getEmployeeId,employeeId);
        List<BackEntity> backEntityList = backMapper.selectList(backWrapper);
        List<ReimburseEntity> reimburseEntityList = reimburseMapper.selectList(reimburseWrapper);

        if (ListUtil.isNotEmpty(backEntityList)||ListUtil.isNotEmpty(reimburseEntityList)) {
                return CommonResponse.error("下游存在引用数据，无法撤回");
        }
        LambdaQueryWrapper<LoadApplyEntity> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(LoadApplyEntity::getId,billId);
        LoadApplyEntity entity = loadApplyService.getOne(wrapper);
        entity.setStatus(1);
        loadApplyService.updateById(entity);

        // TODO
        return CommonResponse.success();
    }

    /**
     * 弃审后事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

}
